#
# spec file for package python-zope.testing
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%{?sle15_python_module_pythons}
Name:           python-zope.testing
Version:        5.0.1
Release:        2.5
Summary:        Zope testing helpers
License:        ZPL-2.1
URL:            https://pypi.python.org/pypi/zope.testing
Source:         https://files.pythonhosted.org/packages/source/z/zope.testing/zope.testing-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
# Test requirements:
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This package provides a number of testing frameworks.

cleanup
  Provides a mixin class for cleaning up after tests that
  make global changes.

formparser
  An HTML parser that extracts form information.

  **Python 2 only**

  This is intended to support functional tests that need to extract
  information from HTML forms returned by the publisher.

  See formparser.txt.

loggingsupport
  Support for testing logging code

  If you want to test that your code generates proper log output, you
  can create and install a handler that collects output.

loghandler
  Logging handler for tests that check logging output.

module
  Lets a doctest pretend to be a Python module.

  See module.txt.

renormalizing
  Regular expression pattern normalizing output checker.
  Useful for doctests.

server
  Provides a simple HTTP server compatible with the zope.app.testing
  functional testing API.  Lets you interactively play with the system
  under test.  Helpful in debugging functional doctest failures.

  **Python 2 only**

setupstack
  A simple framework for automating doctest set-up and tear-down.
  See setupstack.txt.

wait
  A small utility for dealing with timing non-determinism
  See wait.txt.

%prep
%setup -q -n zope.testing-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
pushd build/lib
%pyunittest -v zope.testing.tests.test_suite

%files %{python_files}
%license LICENSE.txt
%doc COPYRIGHT.txt README.rst
%{python_sitelib}/*

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Jan  6 2023 Dirk Müller <dmueller@suse.com>
- update to 5.0.1:
  * Make wheels no longer universal.
  * Backwards incompatible changes
  * Drop support for Python 2.7, 3.5, 3.6.
  * Drop modules which do not seem to be Python compatible:
    + ``zope.testing.loghandler``
    + ``zope.testing.server``
  * Drop doctest option ``IGNORE_EXCEPTION_MODULE_IN_PYTHON2``.
  * Remove functions:
    + ``zope.testing.renormalizing.strip_dottedname_from_traceback``
    + ``zope.testing.renormalizing.is_dotted_name``
  * Add support for Python 3.11.
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.10
  * Show deprecation warnings when importing modules which are not ported to Python 3.
  * Improve test coverage.
  * Port zope.testing.formparser to Python 3.
  * Add support for Python 3.10.
* Tue Oct  5 2021 pgajdos@suse.com
- version update to 4.9
  4.9 (2021-01-08)
  - ---------------
  - Make ``setupstack.txt`` test work again if the current directory is empty.
  4.8 (2021-01-04)
  - ---------------
  - Add support for Python 3.8 and 3.9.
  - Drop support for Python 3.3 and 3.4.
  - Extend IGNORE_EXCEPTION_MODULE_IN_PYTHON2 to cover also exceptions without
    arguments (thus without a colon on the last line of the traceback output).
* Tue Oct  5 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Fri Apr  5 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.7
  * Added support for Python 3.7.
  * Remove dependencies on zope.interface and zope.exceptions.
  * Remove use of 2to3 for outdated versions of PyPy3, letting us
    build universal wheels.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Jun 23 2017 aloisio@gmx.com
- Update to 4.6.1
  * Add support for Python 3.6.
  4.6.0:
  * Introduce option flag ``IGNORE_EXCEPTION_MODULE_IN_PYTHON2``
    to normalize exception class names in traceback output.
    In Python 3 they are displayed as the full dotted name.
    In Python 2 they are displayed as "just" the class name.
    When running doctests in Python 3, the option flag will
    not have any effect, however when running the same test in
    Python 2, the segments in the full dotted name leading up to
    the class name are stripped away from the "expected" string.
  * Drop support for Python 2.6 and 3.2.
  * Add support for Python 3.5.
  * Cleaned up useless 2to3 conversion.
  4.5.0:
  * Added meta data for test case methods created with
    ``zope.testing.doctestcase``.
  * Reasonable values for ``__name__``, making sure that
    ``__name__`` starts with ``test``.
  * For ``doctestfile`` methods, provide ``filename`` and
    ``filepath`` attributes.
    The meta data us useful, for example, for selecting tests
    with the nose attribute mechanism.
  * Added ``doctestcase.doctestfiles``
  * Define multiple doctest files at once.
  * Automatically assign test class members.  So rather than::
    class MYTests(unittest.TestCase):
    ...
    test_foo = doctestcase.doctestfile('foo.txt')
    You can use::
    @doctestcase.doctestfiles('foo.txt', 'bar.txt', ...)
    class MYTests(unittest.TestCase):
    ...
  4.4.0:
  * Added ``zope.testing.setupstack.mock`` as a convenience
    function for setting up mocks in tests.  (The Python
    ``mock`` package must be in the path for this to work. The
    excellent ``mock`` package isn't a dependency of
    ``zope.testing``.)
  * Added the base class ``zope.testing.setupstack.TestCase`` to
    make it much easier to use ``zope.testing.setupstack`` in
    ``unittest`` test cases.
  4.3.0:
  * Added support for creating doctests as methods of
    ``unittest.TestCase`` classes so that they can found
    automatically by test runners, like *nose* that ignore test
    suites.
  4.2.0:
  * **Actually** remove long-deprecated ``zope.testing.doctest``
    (announced as removed in 4.0.0) and
    ``zope.testing.doctestunit``.
  * Add support for PyPy and PyPy3.
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.3:
  * Added support for Python 3.4.
  * Updated boostrap.py to version 2.2.
- switch the source archive to tar.gz (zip not available)
- remove unzip from BuildRequires
- reenable the tests for all suse versions
* Fri Nov  1 2013 p.drouand@gmail.com
- Disable tests; fix build for Factory
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
